import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_mylibrary/base/provider/view_state_model.dart';
import 'package:flutter_mylibrary/config/const.dart';
import 'package:flutter_mylibrary/utils/win_media.dart';
import 'package:flutter_spinkit/flutter_spinkit.dart';

Widget getNoDataWidget({String error = 'No Data'}) => Align(
  alignment: Alignment.center,
  child: Column(
    mainAxisAlignment: MainAxisAlignment.center,
    crossAxisAlignment: CrossAxisAlignment.center,
    children: <Widget>[
      Expanded(
        child: SizedBox(),
        flex: 2,
      ),
      SizedBox(
          width: 100.0,
          height: 100.0,
          child: Image.asset('assets/images/nodata.png')
      ),
      Text(
        error,
        style: TextStyle(fontSize: 16.0, color: Colors.grey[400]),
      ),
      Expanded(
        child: SizedBox(),
        flex: 3,
      ),
    ],
  ),
);


Widget getViewStateWidget(ViewStateModel provider, Function idleWdiget, {Widget busyWidget}){
  if(provider.isIdle){
    return idleWdiget();
  }else if(provider.isError){
    return getNoDataWidget(error: provider.viewStateError.message);
  }else if(provider.isEmpty){
    return getNoDataWidget();
  }else if (provider.isBusy) {
    return busyWidget??pageLoading;
  } else{
    return Container();
  }
}

Widget getRefreshNoDataWidget({ViewStateModel viewStateModel, Widget busyWidget}){
  if(viewStateModel.isError){
    return getNoDataWidget(error: viewStateModel.viewStateError.message);
  }else if(viewStateModel.isEmpty){
    return getNoDataWidget();
  }else if (viewStateModel.isBusy) {
    return busyWidget??pageLoading;
  }else{
    return null;
  }
}




/// 间隔
class Gaps {
  /// 水平间隔
  static Widget hGap5 = new SizedBox(width: getWidth(5));
  static Widget hGap10 = new SizedBox(width: getWidth(10));
  static Widget hGap15 = new SizedBox(width: getWidth(15));
  static Widget hGapDef = new SizedBox(width: getWidth(defaultMargin));

  /// 垂直间隔
  static Widget vGap5 = new SizedBox(height: getHeight(5));
  static Widget vGap10 = new SizedBox(height: getHeight(10));
  static Widget vGap15 = new SizedBox(height: getHeight(15));
  static Widget vGapDef = new SizedBox(width: getHeight(defaultMargin));


  /// 自定义垂直间隔
  static Widget getVertical(double height){
    return SizedBox(
      height: getHeight(height),
    );
  }

  /// 自定义水平间隔
  static Widget getHorizontal(double width){
    return SizedBox(
      width: getHeight(width),
    );
  }
}

